@@ -7,7 +7,7 @@ import numpy as np
 from matplotlib import interactive, is_interactive
 from matplotlib.pyplot import figure as mpl_figure
 from matplotlib.pyplot import install_repl_displayhook, rcParams, uninstall_repl_displayhook
-from numpy import abs, argmin, asarray, take
+from numpy import abs, argmin, asarray
 
 from .deprecations import mpl_interactions_DeprecationWarning
 
